package elpi

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Elpi_trace_atd.Trace_atdSource

Sourcetype builtin_kind = [
  1. | `Logic
  2. | `FFI
]
Sourcetype builtin_rule = {
  1. name : string;
  2. kind : builtin_kind;
  3. payload : string list;
}
Sourcetype chr_text = string
Sourcetype color = [
  1. | `Red
  2. | `Green
  3. | `Grey
  4. | `YellowGreen
  5. | `YellowRed
]
Sourcetype file_location = {
  1. filename : string;
  2. line : int;
  3. column : int;
  4. character : int;
}
Sourcetype goal_id = int
Sourcetype event = [
  1. | `Assign of string
  2. | `Fail of string
  3. | `ResumeGoal of goal_id list
]
Sourcetype goal = {
  1. goal_text : string;
  2. goal_id : goal_id;
}
Sourcetype goal_text = string
Sourcetype outcome = [
  1. | `Fail
  2. | `Success
]
Sourcetype resume = goal list
Sourcetype rule_text = string
Sourcetype runtime_id = int
Sourcetype solution_text = string list
Sourcetype step_id = int
Sourcetype location = [
  1. | `File of file_location
  2. | `Context of step_id
]
Sourcetype user_rule = {
  1. rule_text : rule_text;
  2. rule_loc : location;
}
Sourcetype cutted = {
  1. cut_branch_for_goal : goal;
  2. cut_branch : user_rule;
}
Sourcetype cut = {
  1. cut_goal_id : goal_id;
  2. cut_victims : cutted list;
}
Sourcetype rule = [
  1. | `BuiltinRule of builtin_rule
  2. | `UserRule of user_rule
]
Sourcetype attempt = {
  1. rule : rule;
  2. events : event list;
}
Sourcetype frame = {
  1. rule : rule;
  2. step_id : step_id;
  3. runtime_id : runtime_id;
}
Sourcetype stack = frame list
Sourcetype successful_attempt = {
  1. attempt : attempt;
  2. siblings : goal list;
  3. siblings_aggregated_outcome : outcome;
}
Sourcetype inference = {
  1. current_goal_id : goal_id;
  2. current_goal_text : goal_text;
  3. current_goal_predicate : string;
  4. failed_attempts : attempt list;
  5. successful_attempts : successful_attempt list;
  6. more_successful_attempts : step_id list;
  7. more_failing_attempts : step_id list;
  8. stack : stack;
}
Sourcetype suspend = {
  1. suspend_goal_id : goal_id;
  2. suspend_goal_text : goal_text;
  3. suspend_sibling : goal;
  4. suspend_stack : stack;
}
Sourcetype card = {
  1. step_id : step_id;
  2. runtime_id : runtime_id;
  3. step : step;
  4. color : color;
}
Sourceand chr = {
  1. chr_failed_attempts : chr_attempt list;
  2. chr_successful_attempts : successful_chr_attempt list;
  3. chr_store_before : goal list;
  4. chr_store_after : goal list;
}
Sourceand chr_attempt = {
  1. chr_text : chr_text;
  2. chr_loc : file_location;
  3. chr_condition_cards : trace;
}
Sourceand findall = {
  1. findall_goal_id : goal_id;
  2. findall_goal_text : goal_text;
  3. findall_cards : trace;
  4. findall_solution_text : solution_text;
  5. findall_stack : stack;
}
Sourceand step = [
  1. | `Inference of inference
  2. | `Findall of findall
  3. | `Cut of cut
  4. | `Suspend of suspend
  5. | `Resume of resume
  6. | `CHR of chr
  7. | `Init of goal
]
Sourceand successful_chr_attempt = {
  1. chr_attempt : chr_attempt;
  2. chr_removed_goals : goal_id list;
  3. chr_new_goals : goal list;
}
Sourceand trace = card list
Sourcetype stop = {
  1. cause : string;
  2. time : float;
}
Sourcetype kind = [
  1. | `Start
  2. | `Info
  3. | `Stop of stop
]
Sourcetype item = {
  1. step : int;
  2. kind : kind list;
  3. goal_id : int;
  4. runtime_id : int;
  5. name : string;
  6. payload : string list;
}
Sourcetype raw_trace = item list
Sourceval write_builtin_kind : Stdlib.Buffer.t -> builtin_kind -> unit

Output a JSON value of type builtin_kind.

Sourceval string_of_builtin_kind : ?len:int -> builtin_kind -> string

Serialize a value of type builtin_kind into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_builtin_kind : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> builtin_kind

Input JSON data of type builtin_kind.

Sourceval builtin_kind_of_string : string -> builtin_kind

Deserialize JSON data of type builtin_kind.

Sourceval write_builtin_rule : Stdlib.Buffer.t -> builtin_rule -> unit

Output a JSON value of type builtin_rule.

Sourceval string_of_builtin_rule : ?len:int -> builtin_rule -> string

Serialize a value of type builtin_rule into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_builtin_rule : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> builtin_rule

Input JSON data of type builtin_rule.

Sourceval builtin_rule_of_string : string -> builtin_rule

Deserialize JSON data of type builtin_rule.

Sourceval create_builtin_rule : name:string -> kind:builtin_kind -> payload:string list -> unit -> builtin_rule

Create a record of type builtin_rule.

Sourceval write_chr_text : Stdlib.Buffer.t -> chr_text -> unit

Output a JSON value of type chr_text.

Sourceval string_of_chr_text : ?len:int -> chr_text -> string

Serialize a value of type chr_text into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_chr_text : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> chr_text

Input JSON data of type chr_text.

Sourceval chr_text_of_string : string -> chr_text

Deserialize JSON data of type chr_text.

Sourceval write_color : Stdlib.Buffer.t -> color -> unit

Output a JSON value of type color.

Sourceval string_of_color : ?len:int -> color -> string

Serialize a value of type color into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_color : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> color

Input JSON data of type color.

Sourceval color_of_string : string -> color

Deserialize JSON data of type color.

Sourceval write_file_location : Stdlib.Buffer.t -> file_location -> unit

Output a JSON value of type file_location.

Sourceval string_of_file_location : ?len:int -> file_location -> string

Serialize a value of type file_location into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_file_location : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> file_location

Input JSON data of type file_location.

Sourceval file_location_of_string : string -> file_location

Deserialize JSON data of type file_location.

Sourceval create_file_location : filename:string -> line:int -> column:int -> character:int -> unit -> file_location

Create a record of type file_location.

Sourceval write_goal_id : Stdlib.Buffer.t -> goal_id -> unit

Output a JSON value of type goal_id.

Sourceval string_of_goal_id : ?len:int -> goal_id -> string

Serialize a value of type goal_id into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_goal_id : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> goal_id

Input JSON data of type goal_id.

Sourceval goal_id_of_string : string -> goal_id

Deserialize JSON data of type goal_id.

Sourceval write_event : Stdlib.Buffer.t -> event -> unit

Output a JSON value of type event.

Sourceval string_of_event : ?len:int -> event -> string

Serialize a value of type event into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_event : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> event

Input JSON data of type event.

Sourceval event_of_string : string -> event

Deserialize JSON data of type event.

Sourceval write_goal : Stdlib.Buffer.t -> goal -> unit

Output a JSON value of type goal.

Sourceval string_of_goal : ?len:int -> goal -> string

Serialize a value of type goal into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_goal : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> goal

Input JSON data of type goal.

Sourceval goal_of_string : string -> goal

Deserialize JSON data of type goal.

Sourceval create_goal : goal_text:string -> goal_id:goal_id -> unit -> goal

Create a record of type goal.

Sourceval write_goal_text : Stdlib.Buffer.t -> goal_text -> unit

Output a JSON value of type goal_text.

Sourceval string_of_goal_text : ?len:int -> goal_text -> string

Serialize a value of type goal_text into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_goal_text : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> goal_text

Input JSON data of type goal_text.

Sourceval goal_text_of_string : string -> goal_text

Deserialize JSON data of type goal_text.

Sourceval write_outcome : Stdlib.Buffer.t -> outcome -> unit

Output a JSON value of type outcome.

Sourceval string_of_outcome : ?len:int -> outcome -> string

Serialize a value of type outcome into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_outcome : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> outcome

Input JSON data of type outcome.

Sourceval outcome_of_string : string -> outcome

Deserialize JSON data of type outcome.

Sourceval write_resume : Stdlib.Buffer.t -> resume -> unit

Output a JSON value of type resume.

Sourceval string_of_resume : ?len:int -> resume -> string

Serialize a value of type resume into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_resume : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> resume

Input JSON data of type resume.

Sourceval resume_of_string : string -> resume

Deserialize JSON data of type resume.

Sourceval write_rule_text : Stdlib.Buffer.t -> rule_text -> unit

Output a JSON value of type rule_text.

Sourceval string_of_rule_text : ?len:int -> rule_text -> string

Serialize a value of type rule_text into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_rule_text : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> rule_text

Input JSON data of type rule_text.

Sourceval rule_text_of_string : string -> rule_text

Deserialize JSON data of type rule_text.

Sourceval write_runtime_id : Stdlib.Buffer.t -> runtime_id -> unit

Output a JSON value of type runtime_id.

Sourceval string_of_runtime_id : ?len:int -> runtime_id -> string

Serialize a value of type runtime_id into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_runtime_id : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> runtime_id

Input JSON data of type runtime_id.

Sourceval runtime_id_of_string : string -> runtime_id

Deserialize JSON data of type runtime_id.

Sourceval write_solution_text : Stdlib.Buffer.t -> solution_text -> unit

Output a JSON value of type solution_text.

Sourceval string_of_solution_text : ?len:int -> solution_text -> string

Serialize a value of type solution_text into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_solution_text : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> solution_text

Input JSON data of type solution_text.

Sourceval solution_text_of_string : string -> solution_text

Deserialize JSON data of type solution_text.

Sourceval write_step_id : Stdlib.Buffer.t -> step_id -> unit

Output a JSON value of type step_id.

Sourceval string_of_step_id : ?len:int -> step_id -> string

Serialize a value of type step_id into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_step_id : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> step_id

Input JSON data of type step_id.

Sourceval step_id_of_string : string -> step_id

Deserialize JSON data of type step_id.

Sourceval write_location : Stdlib.Buffer.t -> location -> unit

Output a JSON value of type location.

Sourceval string_of_location : ?len:int -> location -> string

Serialize a value of type location into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_location : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> location

Input JSON data of type location.

Sourceval location_of_string : string -> location

Deserialize JSON data of type location.

Sourceval write_user_rule : Stdlib.Buffer.t -> user_rule -> unit

Output a JSON value of type user_rule.

Sourceval string_of_user_rule : ?len:int -> user_rule -> string

Serialize a value of type user_rule into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_user_rule : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> user_rule

Input JSON data of type user_rule.

Sourceval user_rule_of_string : string -> user_rule

Deserialize JSON data of type user_rule.

Sourceval create_user_rule : rule_text:rule_text -> rule_loc:location -> unit -> user_rule

Create a record of type user_rule.

Sourceval write_cutted : Stdlib.Buffer.t -> cutted -> unit

Output a JSON value of type cutted.

Sourceval string_of_cutted : ?len:int -> cutted -> string

Serialize a value of type cutted into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_cutted : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> cutted

Input JSON data of type cutted.

Sourceval cutted_of_string : string -> cutted

Deserialize JSON data of type cutted.

Sourceval create_cutted : cut_branch_for_goal:goal -> cut_branch:user_rule -> unit -> cutted

Create a record of type cutted.

Sourceval write_cut : Stdlib.Buffer.t -> cut -> unit

Output a JSON value of type cut.

Sourceval string_of_cut : ?len:int -> cut -> string

Serialize a value of type cut into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_cut : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> cut

Input JSON data of type cut.

Sourceval cut_of_string : string -> cut

Deserialize JSON data of type cut.

Sourceval create_cut : cut_goal_id:goal_id -> cut_victims:cutted list -> unit -> cut

Create a record of type cut.

Sourceval write_rule : Stdlib.Buffer.t -> rule -> unit

Output a JSON value of type rule.

Sourceval string_of_rule : ?len:int -> rule -> string

Serialize a value of type rule into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_rule : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> rule

Input JSON data of type rule.

Sourceval rule_of_string : string -> rule

Deserialize JSON data of type rule.

Sourceval write_attempt : Stdlib.Buffer.t -> attempt -> unit

Output a JSON value of type attempt.

Sourceval string_of_attempt : ?len:int -> attempt -> string

Serialize a value of type attempt into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_attempt : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> attempt

Input JSON data of type attempt.

Sourceval attempt_of_string : string -> attempt

Deserialize JSON data of type attempt.

Sourceval create_attempt : rule:rule -> events:event list -> unit -> attempt

Create a record of type attempt.

Sourceval write_frame : Stdlib.Buffer.t -> frame -> unit

Output a JSON value of type frame.

Sourceval string_of_frame : ?len:int -> frame -> string

Serialize a value of type frame into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_frame : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> frame

Input JSON data of type frame.

Sourceval frame_of_string : string -> frame

Deserialize JSON data of type frame.

Sourceval create_frame : rule:rule -> step_id:step_id -> runtime_id:runtime_id -> unit -> frame

Create a record of type frame.

Sourceval write_stack : Stdlib.Buffer.t -> stack -> unit

Output a JSON value of type stack.

Sourceval string_of_stack : ?len:int -> stack -> string

Serialize a value of type stack into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_stack : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> stack

Input JSON data of type stack.

Sourceval stack_of_string : string -> stack

Deserialize JSON data of type stack.

Sourceval write_successful_attempt : Stdlib.Buffer.t -> successful_attempt -> unit

Output a JSON value of type successful_attempt.

Sourceval string_of_successful_attempt : ?len:int -> successful_attempt -> string

Serialize a value of type successful_attempt into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_successful_attempt : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> successful_attempt

Input JSON data of type successful_attempt.

Sourceval successful_attempt_of_string : string -> successful_attempt

Deserialize JSON data of type successful_attempt.

Sourceval create_successful_attempt : attempt:attempt -> siblings:goal list -> siblings_aggregated_outcome:outcome -> unit -> successful_attempt

Create a record of type successful_attempt.

Sourceval write_inference : Stdlib.Buffer.t -> inference -> unit

Output a JSON value of type inference.

Sourceval string_of_inference : ?len:int -> inference -> string

Serialize a value of type inference into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_inference : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> inference

Input JSON data of type inference.

Sourceval inference_of_string : string -> inference

Deserialize JSON data of type inference.

Sourceval create_inference : current_goal_id:goal_id -> current_goal_text:goal_text -> current_goal_predicate:string -> failed_attempts:attempt list -> successful_attempts:successful_attempt list -> more_successful_attempts:step_id list -> ?more_failing_attempts:step_id list -> stack:stack -> unit -> inference

Create a record of type inference.

Sourceval write_suspend : Stdlib.Buffer.t -> suspend -> unit

Output a JSON value of type suspend.

Sourceval string_of_suspend : ?len:int -> suspend -> string

Serialize a value of type suspend into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_suspend : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> suspend

Input JSON data of type suspend.

Sourceval suspend_of_string : string -> suspend

Deserialize JSON data of type suspend.

Sourceval create_suspend : suspend_goal_id:goal_id -> suspend_goal_text:goal_text -> suspend_sibling:goal -> suspend_stack:stack -> unit -> suspend

Create a record of type suspend.

Sourceval write_card : Stdlib.Buffer.t -> card -> unit

Output a JSON value of type card.

Sourceval string_of_card : ?len:int -> card -> string

Serialize a value of type card into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_card : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> card

Input JSON data of type card.

Sourceval card_of_string : string -> card

Deserialize JSON data of type card.

Sourceval create_card : step_id:step_id -> runtime_id:runtime_id -> step:step -> color:color -> unit -> card

Create a record of type card.

Sourceval write_chr : Stdlib.Buffer.t -> chr -> unit

Output a JSON value of type chr.

Sourceval string_of_chr : ?len:int -> chr -> string

Serialize a value of type chr into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_chr : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> chr

Input JSON data of type chr.

Sourceval chr_of_string : string -> chr

Deserialize JSON data of type chr.

Sourceval create_chr : chr_failed_attempts:chr_attempt list -> chr_successful_attempts:successful_chr_attempt list -> chr_store_before:goal list -> chr_store_after:goal list -> unit -> chr

Create a record of type chr.

Sourceval write_chr_attempt : Stdlib.Buffer.t -> chr_attempt -> unit

Output a JSON value of type chr_attempt.

Sourceval string_of_chr_attempt : ?len:int -> chr_attempt -> string

Serialize a value of type chr_attempt into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_chr_attempt : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> chr_attempt

Input JSON data of type chr_attempt.

Sourceval chr_attempt_of_string : string -> chr_attempt

Deserialize JSON data of type chr_attempt.

Sourceval create_chr_attempt : chr_text:chr_text -> chr_loc:file_location -> chr_condition_cards:trace -> unit -> chr_attempt

Create a record of type chr_attempt.

Sourceval write_findall : Stdlib.Buffer.t -> findall -> unit

Output a JSON value of type findall.

Sourceval string_of_findall : ?len:int -> findall -> string

Serialize a value of type findall into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_findall : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> findall

Input JSON data of type findall.

Sourceval findall_of_string : string -> findall

Deserialize JSON data of type findall.

Sourceval create_findall : findall_goal_id:goal_id -> findall_goal_text:goal_text -> findall_cards:trace -> findall_solution_text:solution_text -> findall_stack:stack -> unit -> findall

Create a record of type findall.

Sourceval write_step : Stdlib.Buffer.t -> step -> unit

Output a JSON value of type step.

Sourceval string_of_step : ?len:int -> step -> string

Serialize a value of type step into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_step : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> step

Input JSON data of type step.

Sourceval step_of_string : string -> step

Deserialize JSON data of type step.

Sourceval write_successful_chr_attempt : Stdlib.Buffer.t -> successful_chr_attempt -> unit

Output a JSON value of type successful_chr_attempt.

Sourceval string_of_successful_chr_attempt : ?len:int -> successful_chr_attempt -> string

Serialize a value of type successful_chr_attempt into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_successful_chr_attempt : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> successful_chr_attempt

Input JSON data of type successful_chr_attempt.

Sourceval successful_chr_attempt_of_string : string -> successful_chr_attempt

Deserialize JSON data of type successful_chr_attempt.

Sourceval create_successful_chr_attempt : chr_attempt:chr_attempt -> chr_removed_goals:goal_id list -> chr_new_goals:goal list -> unit -> successful_chr_attempt

Create a record of type successful_chr_attempt.

Sourceval write_trace : Stdlib.Buffer.t -> trace -> unit

Output a JSON value of type trace.

Sourceval string_of_trace : ?len:int -> trace -> string

Serialize a value of type trace into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_trace : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> trace

Input JSON data of type trace.

Sourceval trace_of_string : string -> trace

Deserialize JSON data of type trace.

Sourceval write_stop : Stdlib.Buffer.t -> stop -> unit

Output a JSON value of type stop.

Sourceval string_of_stop : ?len:int -> stop -> string

Serialize a value of type stop into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_stop : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> stop

Input JSON data of type stop.

Sourceval stop_of_string : string -> stop

Deserialize JSON data of type stop.

Sourceval create_stop : cause:string -> time:float -> unit -> stop

Create a record of type stop.

Sourceval write_kind : Stdlib.Buffer.t -> kind -> unit

Output a JSON value of type kind.

Sourceval string_of_kind : ?len:int -> kind -> string

Serialize a value of type kind into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_kind : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> kind

Input JSON data of type kind.

Sourceval kind_of_string : string -> kind

Deserialize JSON data of type kind.

Sourceval write_item : Stdlib.Buffer.t -> item -> unit

Output a JSON value of type item.

Sourceval string_of_item : ?len:int -> item -> string

Serialize a value of type item into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_item : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> item

Input JSON data of type item.

Sourceval item_of_string : string -> item

Deserialize JSON data of type item.

Sourceval create_item : step:int -> kind:kind list -> goal_id:int -> runtime_id:int -> name:string -> payload:string list -> unit -> item

Create a record of type item.

Sourceval write_raw_trace : Stdlib.Buffer.t -> raw_trace -> unit

Output a JSON value of type raw_trace.

Sourceval string_of_raw_trace : ?len:int -> raw_trace -> string

Serialize a value of type raw_trace into a JSON string.

  • parameter len

    specifies the initial length of the buffer used internally. Default: 1024.

Sourceval read_raw_trace : Yojson.Safe.lexer_state -> Stdlib.Lexing.lexbuf -> raw_trace

Input JSON data of type raw_trace.

Sourceval raw_trace_of_string : string -> raw_trace

Deserialize JSON data of type raw_trace.